@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-""" The Elastic Ensemble (EE)
-    An ensemble of elastic nearest neighbour classifiers
+"""The Elastic Ensemble (EE).
+
+An ensemble of elastic nearest neighbour classifiers.
 """
 
-__author__ = "Jason Lines"
+__author__ = ["jasonlines"]
 __all__ = ["ElasticEnsemble"]
 
 import os
@@ -11,14 +12,17 @@ import time
 from itertools import product
 
 import numpy as np
+import pandas as pd
 from sklearn.metrics import accuracy_score
-from sklearn.model_selection import GridSearchCV
-from sklearn.model_selection import LeaveOneOut
-from sklearn.model_selection import RandomizedSearchCV
-from sklearn.model_selection import StratifiedShuffleSplit
-from sklearn.model_selection import cross_val_predict
+from sklearn.model_selection import (
+    GridSearchCV,
+    LeaveOneOut,
+    RandomizedSearchCV,
+    StratifiedShuffleSplit,
+    cross_val_predict,
+)
 from sklearn.preprocessing import LabelEncoder
-from sklearn.utils.multiclass import class_distribution
+
 from sktime.classification.base import BaseClassifier
 from sktime.classification.distance_based._time_series_neighbors import (
     KNeighborsTimeSeriesClassifier,
@@ -31,42 +35,30 @@ from sktime.distances.elastic_cython import msm_distance as msm_c
 from sktime.distances.elastic_cython import wddtw_distance as wddtw_c
 from sktime.distances.elastic_cython import wdtw_distance as wdtw_c
 from sktime.transformations.panel.summarize import DerivativeSlopeTransformer
-from sktime.utils.validation.panel import check_X
-from sktime.utils.validation.panel import check_X_y
 
 
 class ElasticEnsemble(BaseClassifier):
-    """
-    The Elastic Ensemble (EE) as described in Jason Lines and Anthony Bagnall,
-    "Time Series Classification with Ensembles of Elastic Distance Measures",
-    Data Mining and Knowledge Discovery, 29(3), 2015.
+    """The Elastic Ensemble (EE).
 
-    https://link.springer.com/article/10.1007/s10618-014-0361-2
+    EE as described in [1].
 
     Overview:
 
     - Input n series length m
     - EE is an ensemble of elastic nearest neighbor classifiers
 
-    .. note::
-
-        For the original Java version, see `ElasticEnsemble <https://github.com
-        /uea-machine-learning/tsml/blob/master/src/main/java/tsml/classifiers/
-        distance_based/ElasticEnsemble.java>`__.
-
     Parameters
     ----------
     distance_measures : list of strings, optional (default="all")
       A list of strings identifying which distance measures to include.
-    proportion_of_param_option : float, optional (default=1)
+    proportion_of_param_options : float, optional (default=1)
       The proportion of the parameter grid space to search optional.
     proportion_train_in_param_finding : float, optional (default=1)
       The proportion of the train set to use in the parameter search optional.
     proportion_train_for_test : float, optional (default=1)
       The proportion of the train set to use in classifying new cases optional.
-    n_jobs : int or None, optional (default=None)
+    n_jobs : int, optional (default=1)
       The number of jobs to run in parallel for both `fit` and `predict`.
-      ``None`` means 1 unless in a :obj:`joblib.parallel_backend` context.
       ``-1`` means using all processors.
     random_state : int, default=0
       The random seed.
@@ -81,13 +73,31 @@ class ElasticEnsemble(BaseClassifier):
       Store the train accuracies of the classifiers
     train_preds_by_classifier : list
       Store the train predictions of each classifier
+
+    Notes
+    -----
+    ..[1] Jason Lines and Anthony Bagnall,
+          "Time Series Classification with Ensembles of Elastic Distance Measures",
+              Data Mining and Knowledge Discovery, 29(3), 2015.
+    https://link.springer.com/article/10.1007/s10618-014-0361-2
+
+    Examples
+    --------
+    >>> from sktime.classification.distance_based import ElasticEnsemble
+    >>> from sktime.datasets import load_unit_test
+    >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
+    >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
+    >>> clf = ElasticEnsemble(
+    ...     proportion_of_param_options=0.1,
+    ...     proportion_train_for_test=0.1,
+    ... )
+    >>> clf.fit(X_train, y_train)
+    ElasticEnsemble(...)
+    >>> y_pred = clf.predict(X_test)
     """
 
-    # Capabilities: data types this classifier can handle
-    capabilities = {
-        "multivariate": False,
-        "unequal_length": False,
-        "missing_values": False,
+    _tags = {
+        "capability:multithreading": True,
     }
 
     def __init__(
@@ -96,7 +106,7 @@ class ElasticEnsemble(BaseClassifier):
         proportion_of_param_options=1.0,
         proportion_train_in_param_finding=1.0,
         proportion_train_for_test=1.0,
-        n_jobs=None,
+        n_jobs=1,
         random_state=0,
         verbose=0,
     ):
@@ -118,16 +128,17 @@ class ElasticEnsemble(BaseClassifier):
         self.estimators_ = None
         self.train_accs_by_classifier = None
         self.train_preds_by_classifier = None
-        self.classes_ = None
         self.n_jobs = n_jobs
         self.random_state = random_state
         self.verbose = verbose
         self.train = None
         self.constituent_build_times = None
+
         super(ElasticEnsemble, self).__init__()
 
-    def fit(self, X, y):
-        """Build an ensemble of 1-NN classifiers from the training set (X, y),
+    def _fit(self, X, y):
+        """Build an ensemble of 1-NN classifiers from the training set (X, y).
+
         Parameters
         ----------
         X : array-like or sparse matrix of shape = [n_instances, n_columns]
@@ -140,9 +151,6 @@ class ElasticEnsemble(BaseClassifier):
         -------
         self : object
         """
-
-        X, y = check_X_y(X, y, enforce_univariate=True, coerce_to_pandas=True)
-
         # Derivative DTW (DDTW) uses the regular DTW algorithm on data that
         # are transformed into derivatives.
         # To increase the efficiency of DDTW we can pre-transform the data
@@ -156,19 +164,20 @@ class ElasticEnsemble(BaseClassifier):
         ) or self.distance_measures.__contains__(wddtw_c):
             der_X = DerivativeSlopeTransformer().fit_transform(X)
             # reshape X for use with the efficient cython distance measures
-            der_X = np.array(
-                [np.asarray([x]).reshape(len(x), 1) for x in der_X.iloc[:, 0]]
-            )
+            if isinstance(X, pd.DataFrame):
+                der_X = np.array(
+                    [np.asarray([x]).reshape(1, len(x)) for x in der_X.iloc[:, 0]]
+                )
         else:
             der_X = None
 
         # reshape X for use with the efficient cython distance measures
-        X = np.array([np.asarray([x]).reshape(len(x), 1) for x in X.iloc[:, 0]])
+        if isinstance(X, pd.DataFrame):
+            X = np.array([np.asarray([x]).reshape(1, len(x)) for x in X.iloc[:, 0]])
 
         self.train_accs_by_classifier = np.zeros(len(self.distance_measures))
         self.train_preds_by_classifier = [None] * len(self.distance_measures)
         self.estimators_ = [None] * len(self.distance_measures)
-        self.classes_ = class_distribution(np.asarray(y).reshape(-1, 1))[0][0]
         rand = np.random.RandomState(self.random_state)
 
         # The default EE uses all training instances for setting parameters,
@@ -275,14 +284,14 @@ class ElasticEnsemble(BaseClassifier):
 
                 grid = GridSearchCV(
                     estimator=KNeighborsTimeSeriesClassifier(
-                        metric=this_measure, n_neighbors=1, algorithm="brute"
+                        distance=this_measure, n_neighbors=1
                     ),
                     param_grid=ElasticEnsemble._get_100_param_options(
                         self.distance_measures[dm], X
                     ),
                     cv=LeaveOneOut(),
                     scoring="accuracy",
-                    n_jobs=self.n_jobs,
+                    n_jobs=self._threads_to_use,
                     verbose=self.verbose,
                 )
                 grid.fit(param_train_to_use, param_train_y)
@@ -292,7 +301,7 @@ class ElasticEnsemble(BaseClassifier):
             else:
                 grid = RandomizedSearchCV(
                     estimator=KNeighborsTimeSeriesClassifier(
-                        metric=this_measure, n_neighbors=1, algorithm="brute"
+                        distance=this_measure, n_neighbors=1
                     ),
                     param_distributions=ElasticEnsemble._get_100_param_options(
                         self.distance_measures[dm], X
@@ -300,7 +309,7 @@ class ElasticEnsemble(BaseClassifier):
                     n_iter=100 * self.proportion_of_param_options,
                     cv=LeaveOneOut(),
                     scoring="accuracy",
-                    n_jobs=self.n_jobs,
+                    n_jobs=self._threads_to_use,
                     random_state=rand,
                     verbose=self.verbose,
                 )
@@ -313,10 +322,10 @@ class ElasticEnsemble(BaseClassifier):
             # was used previously. TO-DO: determine how to extract
             # predictions for the best param option from GridSearchCV)
             best_model = KNeighborsTimeSeriesClassifier(
-                algorithm="brute",
                 n_neighbors=1,
-                metric=this_measure,
-                metric_params=grid.best_params_["metric_params"],
+                distance=this_measure,
+                distance_params=grid.best_params_["distance_params"],
+                n_jobs=self._threads_to_use,
             )
             preds = cross_val_predict(
                 best_model, full_train_to_use, y, cv=LeaveOneOut()
@@ -330,17 +339,16 @@ class ElasticEnsemble(BaseClassifier):
                     + ": "
                     + str(acc)
                     + " (with parameter setting: "
-                    + str(grid.best_params_["metric_params"])
+                    + str(grid.best_params_["distance_params"])
                     + ")"
                 )
 
             # Finally, reset the classifier for this measure and parameter
             # option, ready to be called for test classification
             best_model = KNeighborsTimeSeriesClassifier(
-                algorithm="brute",
                 n_neighbors=1,
-                metric=this_measure,
-                metric_params=grid.best_params_["metric_params"],
+                distance=this_measure,
+                distance_params=grid.best_params_["distance_params"],
             )
             best_model.fit(full_train_to_use, y)
             end_build_time = time.time()
@@ -350,13 +358,19 @@ class ElasticEnsemble(BaseClassifier):
             self.train_accs_by_classifier[dm] = acc
             self.train_preds_by_classifier[dm] = preds
 
-        self._is_fitted = True
         return self
 
-    def predict_proba(self, X):
-        self.check_is_fitted()
-        X = check_X(X, enforce_univariate=True, coerce_to_pandas=True)
+    def _predict_proba(self, X):
+        """Predict class probabilities for n instances in X.
 
+        Parameters
+        ----------
+        X : pd.DataFrame of shape [n, 1]
+
+        Returns
+        -------
+        array of shape [n, self.n_classes]
+        """
         # Derivative DTW (DDTW) uses the regular DTW algorithm on data that
         # are transformed into derivatives.
         # To increase the efficiency of DDTW we can pre-transform the data
@@ -369,14 +383,16 @@ class ElasticEnsemble(BaseClassifier):
             ddtw_c
         ) or self.distance_measures.__contains__(wddtw_c):
             der_X = DerivativeSlopeTransformer().fit_transform(X)
-            der_X = np.array(
-                [np.asarray([x]).reshape(len(x), 1) for x in der_X.iloc[:, 0]]
-            )
+            if isinstance(X, pd.DataFrame):
+                der_X = np.array(
+                    [np.asarray([x]).reshape(1, len(x)) for x in der_X.iloc[:, 0]]
+                )
         else:
             der_X = None
 
         # reshape X for use with the efficient cython distance measures
-        X = np.array([np.asarray([x]).reshape(len(x), 1) for x in X.iloc[:, 0]])
+        if isinstance(X, pd.DataFrame):
+            X = np.array([np.asarray([x]).reshape(1, len(x)) for x in X.iloc[:, 0]])
 
         output_probas = []
         train_sum = 0
@@ -400,8 +416,18 @@ class ElasticEnsemble(BaseClassifier):
         output_probas = np.divide(output_probas, train_sum)
         return output_probas
 
-    def predict(self, X, return_preds_and_probas=False):
-        probas = self.predict_proba(X)  # does derivative transform within (if required)
+    def _predict(self, X, return_preds_and_probas=False):
+        """Predict class values of n instances in X.
+
+        Parameters
+        ----------
+        X : pd.DataFrame of shape [n, 1]
+        return_preds_and_probas: boolean option to return predictions
+        Returns
+        -------
+        array of shape [n, 1]
+        """
+        probas = self._predict_proba(X)  # does derivative transform within if required
         idx = np.argmax(probas, axis=1)
         preds = np.asarray([self.classes_[x] for x in idx])
         if return_preds_and_probas is False:
@@ -410,6 +436,7 @@ class ElasticEnsemble(BaseClassifier):
             return preds, probas
 
     def get_train_probs(self, X=None):
+        """Find and returns the probability estimates for data X."""
         num_cases = len(self.train_preds_by_classifier[0])
         num_classes = len(self.classes_)
         num_estimators = len(self.estimators_)
@@ -426,13 +453,14 @@ class ElasticEnsemble(BaseClassifier):
         return probs
 
     def get_metric_params(self):
+        """Return the parameters for the distance metrics used."""
         return {
             self.distance_measures[dm].__name__: str(self.estimators_[dm].metric_params)
             for dm in range(len(self.estimators_))
         }
 
     def write_constituent_train_files(self, output_file_path, dataset_name, actual_y):
-
+        """Write the train information to file in UEA format."""
         for c in range(len(self.estimators_)):
             measure_name = self.distance_measures[c].__name__
 
@@ -503,9 +531,9 @@ class ElasticEnsemble(BaseClassifier):
             return np.arange(min_val, max_val + inc / 2, inc)
 
         if distance_measure == dtw_c or distance_measure == ddtw_c:
-            return {"metric_params": [{"w": x / 100} for x in range(0, 100)]}
+            return {"distance_params": [{"w": x / 100} for x in range(0, 100)]}
         elif distance_measure == wdtw_c or distance_measure == wddtw_c:
-            return {"metric_params": [{"g": x / 100} for x in range(0, 100)]}
+            return {"distance_params": [{"g": x / 100} for x in range(0, 100)]}
         elif distance_measure == lcss_c:
             train_std = np.std(train_x)
             epsilons = get_inclusive(train_std * 0.2, train_std, 10)
@@ -513,7 +541,7 @@ class ElasticEnsemble(BaseClassifier):
             deltas = [int(d) for d in deltas]
             a = list(product(epsilons, deltas))
             return {
-                "metric_params": [
+                "distance_params": [
                     {"epsilon": a[x][0], "delta": a[x][1]} for x in range(0, len(a))
                 ]
             }
@@ -523,7 +551,7 @@ class ElasticEnsemble(BaseClassifier):
             g_vals = get_inclusive(train_std * 0.2, train_std, 10)
             b_and_g = list(product(band_sizes, g_vals))
             return {
-                "metric_params": [
+                "distance_params": [
                     {"band_size": b_and_g[x][0], "g": b_and_g[x][1]}
                     for x in range(0, len(b_and_g))
                 ]
@@ -534,7 +562,7 @@ class ElasticEnsemble(BaseClassifier):
             c = get_inclusive(1, 10, 26)
             d = get_inclusive(10, 100, 26)
             return {
-                "metric_params": [
+                "distance_params": [
                     {"c": x} for x in np.concatenate([a, b[1:], c[1:], d[1:]])
                 ]
             }
