@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
+"""Interval based time series classifiers."""
 __all__ = [
     "TimeSeriesForestClassifier",
     "RandomIntervalSpectralForest",
+    "RandomIntervalSpectralEnsemble",
     "SupervisedTimeSeriesForest",
     "CanonicalIntervalForest",
     "DrCIF",
@@ -9,6 +11,9 @@ __all__ = [
 
 from sktime.classification.interval_based._cif import CanonicalIntervalForest
 from sktime.classification.interval_based._drcif import DrCIF
-from sktime.classification.interval_based._rise import RandomIntervalSpectralForest
+from sktime.classification.interval_based._rise import (
+    RandomIntervalSpectralForest,  # todo remove in 0.10.0
+)
+from sktime.classification.interval_based._rise import RandomIntervalSpectralEnsemble
 from sktime.classification.interval_based._stsf import SupervisedTimeSeriesForest
 from sktime.classification.interval_based._tsf import TimeSeriesForestClassifier
