@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """CIF classifier.
 
-interval based CIF classifier extracting catch22 features from random intervals.
+Interval based CIF classifier extracting catch22 features from random intervals.
 """
 
 __author__ = ["MatthewMiddlehurst"]
@@ -14,16 +14,14 @@ from joblib import Parallel, delayed
 from sklearn.base import BaseEstimator
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.utils import check_random_state
-from sklearn.utils.multiclass import class_distribution
 
 from sktime.base._base import _clone_estimator
 from sktime.classification.base import BaseClassifier
 from sktime.contrib.vector_classifiers._continuous_interval_tree import (
-    _cif_feature,
     ContinuousIntervalTree,
+    _cif_feature,
 )
 from sktime.transformations.panel.catch22 import Catch22
-from sktime.utils.validation import check_n_jobs
 
 
 class CanonicalIntervalForest(BaseClassifier):
@@ -70,24 +68,24 @@ class CanonicalIntervalForest(BaseClassifier):
 
     Attributes
     ----------
-    n_classes : int
+    n_classes_ : int
         The number of classes.
-    n_instances : int
+    n_instances_ : int
         The number of train cases.
-    n_dims : int
+    n_dims_ : int
         The number of dimensions per case.
-    series_length : int
+    series_length_ : int
         The length of each series.
     classes_ : list
         The classes labels.
     estimators_ : list of shape (n_estimators) of BaseEstimator
         The collections of estimators trained in fit.
-    intervals : list of shape (n_estimators) of ndarray with shape (n_intervals,2)
+    intervals_ : list of shape (n_estimators) of ndarray with shape (n_intervals,2)
         Stores indexes of each intervals start and end points for all classifiers.
-    atts : list of shape (n_estimators) of array with shape (att_subsample_size)
+    atts_ : list of shape (n_estimators) of array with shape (att_subsample_size)
         Attribute indexes of the subsampled catch22 or summary statistic for all
         classifiers.
-    dims : list of shape (n_estimators) of array with shape (n_intervals)
+    dims_ : list of shape (n_estimators) of array with shape (n_intervals)
         The dimension to extract attributes from each interval for all classifiers.
 
     See Also
@@ -120,10 +118,7 @@ class CanonicalIntervalForest(BaseClassifier):
 
     _tags = {
         "capability:multivariate": True,
-        "capability:unequal_length": False,
-        "capability:missing_values": False,
-        "capability:train_estimate": False,
-        "capability:contractable": False,
+        "capability:multithreading": True,
     }
 
     def __init__(
@@ -148,31 +143,24 @@ class CanonicalIntervalForest(BaseClassifier):
         self.n_jobs = n_jobs
 
         # The following set in method fit
-        self.n_classes = 0
-        self.n_instances = 0
-        self.n_dims = 0
-        self.series_length = 0
-        self.classes_ = []
+        self.n_instances_ = 0
+        self.n_dims_ = 0
+        self.series_length_ = 0
         self.estimators_ = []
-        self.intervals = []
-        self.atts = []
-        self.dims = []
+        self.intervals_ = []
+        self.atts_ = []
+        self.dims_ = []
 
         self._n_intervals = n_intervals
         self._att_subsample_size = att_subsample_size
         self._max_interval = max_interval
         self._min_interval = min_interval
         self._base_estimator = base_estimator
-        self._n_jobs = n_jobs
 
         super(CanonicalIntervalForest, self).__init__()
 
     def _fit(self, X, y):
-        self._n_jobs = check_n_jobs(self.n_jobs)
-
-        self.n_instances, self.n_dims, self.series_length = X.shape
-        self.n_classes = np.unique(y).shape[0]
-        self.classes_ = class_distribution(np.asarray(y).reshape(-1, 1))[0][0]
+        self.n_instances_, self.n_dims_, self.series_length_ = X.shape
 
         if self.base_estimator == "DTC":
             self._base_estimator = DecisionTreeClassifier(criterion="entropy")
@@ -185,7 +173,7 @@ class CanonicalIntervalForest(BaseClassifier):
 
         if self.n_intervals is None:
             self._n_intervals = int(
-                math.sqrt(self.series_length) * math.sqrt(self.n_dims)
+                math.sqrt(self.series_length_) * math.sqrt(self.n_dims_)
             )
         if self._n_intervals <= 0:
             self._n_intervals = 1
@@ -193,17 +181,17 @@ class CanonicalIntervalForest(BaseClassifier):
         if self.att_subsample_size > 25:
             self._att_subsample_size = 25
 
-        if self.series_length < self.min_interval:
-            self._min_interval = self.series_length
+        if self.series_length_ < self.min_interval:
+            self._min_interval = self.series_length_
         elif self.min_interval < 3:
             self._min_interval = 3
 
         if self.max_interval is None:
-            self._max_interval = self.series_length / 2
+            self._max_interval = self.series_length_ / 2
         if self._max_interval < self._min_interval:
             self._max_interval = self._min_interval
 
-        fit = Parallel(n_jobs=self._n_jobs)(
+        fit = Parallel(n_jobs=self._threads_to_use)(
             delayed(self._fit_estimator)(
                 X,
                 y,
@@ -212,7 +200,9 @@ class CanonicalIntervalForest(BaseClassifier):
             for i in range(self.n_estimators)
         )
 
-        self.estimators_, self.intervals, self.dims, self.atts = zip(*fit)
+        self.estimators_, self.intervals_, self.dims_, self.atts_ = zip(*fit)
+
+        return self
 
     def _predict(self, X):
         rng = check_random_state(self.random_state)
@@ -225,25 +215,25 @@ class CanonicalIntervalForest(BaseClassifier):
 
     def _predict_proba(self, X):
         n_test_instances, _, series_length = X.shape
-        if series_length != self.series_length:
-            raise TypeError(
+        if series_length != self.series_length_:
+            raise ValueError(
                 "ERROR number of attributes in the train does not match "
                 "that in the test data"
             )
 
-        y_probas = Parallel(n_jobs=self._n_jobs)(
+        y_probas = Parallel(n_jobs=self._threads_to_use)(
             delayed(self._predict_proba_for_estimator)(
                 X,
                 self.estimators_[i],
-                self.intervals[i],
-                self.dims[i],
-                self.atts[i],
+                self.intervals_[i],
+                self.dims_[i],
+                self.atts_[i],
             )
             for i in range(self.n_estimators)
         )
 
         output = np.sum(y_probas, axis=0) / (
-            np.ones(self.n_classes) * self.n_estimators
+            np.ones(self.n_classes_) * self.n_estimators
         )
         return output
 
@@ -254,12 +244,12 @@ class CanonicalIntervalForest(BaseClassifier):
         rng = check_random_state(rs)
 
         transformed_x = np.empty(
-            shape=(self._att_subsample_size * self._n_intervals, self.n_instances),
+            shape=(self._att_subsample_size * self._n_intervals, self.n_instances_),
             dtype=np.float32,
         )
 
         atts = rng.choice(25, self._att_subsample_size, replace=False)
-        dims = rng.choice(self.n_dims, self._n_intervals, replace=True)
+        dims = rng.choice(self.n_dims_, self._n_intervals, replace=True)
         intervals = np.zeros((self._n_intervals, 2), dtype=int)
 
         # Find the random intervals for classifier i and concatenate
@@ -267,19 +257,21 @@ class CanonicalIntervalForest(BaseClassifier):
         for j in range(0, self._n_intervals):
             if rng.random() < 0.5:
                 intervals[j][0] = rng.randint(
-                    0, self.series_length - self._min_interval
+                    0, self.series_length_ - self._min_interval
                 )
                 len_range = min(
-                    self.series_length - intervals[j][0],
+                    self.series_length_ - intervals[j][0],
                     self._max_interval,
                 )
                 length = (
                     rng.randint(0, len_range - self._min_interval) + self._min_interval
+                    if len_range - self._min_interval > 0
+                    else self._min_interval
                 )
                 intervals[j][1] = intervals[j][0] + length
             else:
                 intervals[j][1] = (
-                    rng.randint(0, self.series_length - self._min_interval)
+                    rng.randint(0, self.series_length_ - self._min_interval)
                     + self._min_interval
                 )
                 len_range = min(intervals[j][1], self._max_interval)
@@ -332,9 +324,9 @@ class CanonicalIntervalForest(BaseClassifier):
                 " be ContinuousIntervalTree."
             )
 
-        curves = np.zeros((25, self.n_dims, self.series_length))
+        curves = np.zeros((25, self.n_dims_, self.series_length_))
         if normalise_time_points:
-            counts = np.zeros((25, self.n_dims, self.series_length))
+            counts = np.zeros((25, self.n_dims_, self.series_length_))
 
         for i, tree in enumerate(self.estimators_):
             splits, gains = tree.tree_node_splits_and_gain()
@@ -342,15 +334,15 @@ class CanonicalIntervalForest(BaseClassifier):
             for n, split in enumerate(splits):
                 gain = gains[n]
                 interval = int(split / self._att_subsample_size)
-                att = self.atts[i][int(split % self._att_subsample_size)]
-                dim = self.dims[i][interval]
+                att = self.atts_[i][int(split % self._att_subsample_size)]
+                dim = self.dims_[i][interval]
 
                 for j in range(
-                    self.intervals[i][interval][0], self.intervals[i][interval][1] + 1
+                    self.intervals_[i][interval][0], self.intervals_[i][interval][1] + 1
                 ):
                     curves[att][dim][j] += gain
                     if normalise_time_points:
-                        curves[att][dim][j] += 1
+                        counts[att][dim][j] += 1
 
         if normalise_time_points:
             counts = counts / self.n_estimators / self._n_intervals
