@@ -1,12 +1,34 @@
 # -*- coding: utf-8 -*-
+"""Elastic Ensemble classifier from file."""
+__author__ = "Jason Lines"
+
 import numpy as np
 import os
 from sklearn.metrics import accuracy_score
-from sktime.contrib.classification_experiments import write_results_to_uea_format
+from sktime.utils.data_io import write_results_to_uea_format
 
 
 class ElasticEnsemblePostProcess:
-    __author__ = "Jason Lines"
+    """Elastic Ensemble post processor.
+
+    Parameters
+    ----------
+    results_path: str
+        path to folder storing the results to be read into the ensemble
+    dataset_name: str
+        the name of the dataset that this ensemble will post process results for
+    distance_measures: 'all' or list of Strings, default 'all'
+        'all' sets classifier to use all default constituent classifiers, else a list is
+        provided of classifiers to include. Note these names must match the names of the
+        subdirs in the folder located at results_parh
+    resample_id: int, default = 0
+        to identify the deterministic seed used for resampling experiments. A
+        resampled_id of 0 demonstrates default train/test split were used to create
+        results
+    alpha: float or double, default=1.0.
+        Used to exponentiate the confidence of constituent classifiers when making
+        test predictions
+    """
 
     def __init__(
         self,
@@ -16,18 +38,6 @@ class ElasticEnsemblePostProcess:
         resample_id=0,
         alpha=1,
     ):
-        """
-
-        Args:
-            results_path: String - path to folder storing the results to be read into the ensemble
-            dataset_name: String - the name of the dataset that this ensemble will post process results for
-            distance_measures: 'all' or list of Strings - default 'all'. 'all' sets classifier to use all default constituent classifiers,
-                                else a list is provided of classifiers to include. Note these names must match the names of
-                                the subdirs in the folder located at results_parh
-            resample_id: default = 0 - to identify the deterministic seed used for resampling experiments.
-                         A resampled_id of 0 demonstrates default train/test split were used to create results
-            alpha: float/double - default=1.0. Used to exponentiate the confidence of constituent classifiers when making test predictions
-        """
         self.results_path = results_path
         self.dataset_name = dataset_name
         self.resample_id = resample_id
@@ -202,20 +212,25 @@ class ElasticEnsemblePostProcess:
         overwrite=False,
     ):
         """
+        Write the results to file.
 
-        Args:
-            output_results_path: String - path to where output results will be written
-            output_classifier_name: String - the name of the composite ensemble classifier in the output files
-            write_train: boolean - true will write train files for the ensemble, false will skip training files
-            write_test: boolean - true will write test files for the ensemble, false will skip test files
-            overwrite: boolean - if true, any existing train/test files will be over-written. False prevents file overwriting
-
+        Probably could be replaced with data_io.write_results_UEA
 
+        Parameters
+        ----------
+        output_results_path : str
+            path to where output results will be written
+        output_classifier_name : str
+            the name of the composite ensemble classifier in the output files
+        write_train : boolean
+            true will write train files for the ensemble, false will skip training files
+        write_test : boolean
+            true will write test files for the ensemble, false will skip test files
+        overwrite: boolean
+            if true, any existing train/test files will be over-written. False
+            prevents file overwriting
         """
         if write_train is False and write_test is False:
-            print(
-                "Train and test writing both set to false - method will terminate without doing anything"
-            )
             return
 
         if not overwrite:
@@ -231,11 +246,6 @@ class ElasticEnsemblePostProcess:
                     + ".csv"
                 )
                 if os.path.exists(full_path):
-                    print(
-                        full_path
-                        + " already exists and overwrite set to false, not writing Train",
-                        Warning,
-                    )
                     write_train = False
 
             if write_test is True:
@@ -257,25 +267,7 @@ class ElasticEnsemblePostProcess:
                     write_test = False
 
         if write_train is False and write_test is False:
-            print(
-                "Train and test files both already exist and overwrite set to false - method will terminate without doing anything"
-            )
             return
-
-        """
-        file_format = None
-        if os.path.exists(problem_path + self.dataset_name + '/' + self.dataset_name+ '_TRAIN.ts') and os.path.exists(problem_path + self.dataset_name + '/' + self.dataset_name+ '_TEST.ts'):
-            train_x, train_y = loader.load_from_tsfile_to_dataframe(problem_path + self.dataset_name + '/' + self.dataset_name + '_TRAIN.ts')
-            test_x, test_y = loader.load_from_tsfile_to_dataframe(problem_path + self.dataset_name + '/' + self.dataset_name + '_TEST.ts')
-        elif os.path.exists(problem_path + self.dataset_name + '/' + self.dataset_name+ '_TRAIN.arff') and os.path.exists(problem_path + self.dataset_name + '/' + self.dataset_name+ '_TEST.arff'):
-            train_x, train_y = loader.load_from_arff_to_dataframe(problem_path + self.dataset_name + '/' + self.dataset_name + '_TRAIN.ts')
-            test_x, test_y = loader.load_from_arff_to_dataframe(problem_path + self.dataset_name + '/' + self.dataset_name + '_TEST.ts')
-        elif os.path.exists(problem_path + self.dataset_name + '/' + self.dataset_name + '_TRAIN.tsv') and os.path.exists(problem_path + self.dataset_name + '/' + self.dataset_name + '_TEST.tsv'):
-            train_x, train_y = loader.load_from_ucr_tsv_to_dataframe(problem_path + self.dataset_name + '/' + self.dataset_name + '_TRAIN.ts')
-            test_x, test_y = loader.load_from_ucr_tsv_to_dataframe(problem_path + self.dataset_name + '/' + self.dataset_name + '_TEST.ts')
-        else:
-            raise ValueError("No dataset found for "+self.dataset_name)
-        """
         if write_train:
             train_probs = self.ee_train_dists
             train_preds = self.classes_[np.argmax(train_probs, axis=1)]
@@ -295,7 +287,7 @@ class ElasticEnsemblePostProcess:
                 classifier_name=output_classifier_name,
                 resample_seed=self.resample_id,
                 predicted_class_vals=train_preds,
-                actual_probas=train_probs,
+                predicted_probs=train_probs,
                 dataset_name=self.dataset_name,
                 actual_class_vals=self.actual_train_class_vals,
                 split="TRAIN",
@@ -320,7 +312,7 @@ class ElasticEnsemblePostProcess:
                 classifier_name=output_classifier_name,
                 resample_seed=self.resample_id,
                 predicted_class_vals=test_preds,
-                actual_probas=test_probs,
+                predicted_probs=test_probs,
                 dataset_name=self.dataset_name,
                 actual_class_vals=self.actual_test_class_vals,
                 split="TEST",
