@@ -21,14 +21,13 @@ __all__ = [
     "get_examples",
 ]
 
-
-from sktime.datatypes._series import example_dict_Series
-from sktime.datatypes._series import example_dict_lossy_Series
-from sktime.datatypes._panel import example_dict_Panel
-from sktime.datatypes._panel import example_dict_lossy_Panel
+from sktime.datatypes._alignment import example_dict_Alignment
+from sktime.datatypes._panel import example_dict_lossy_Panel, example_dict_Panel
+from sktime.datatypes._series import example_dict_lossy_Series, example_dict_Series
 
 # pool example_dict-s
 example_dict = dict()
+example_dict.update(example_dict_Alignment)
 example_dict.update(example_dict_Series)
 example_dict.update(example_dict_Panel)
 
